OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Përshëndetje %s",
    "Hello %s," : "Përshëndetje %s,",
    "Notifications" : "Njoftimet",
    "Dismiss" : "Hiq",
    "in {path}" : "në {path}",
    "No notifications" : "Asnjë njoftim",
    "Never" : "Kurrë",
    "1 hour" : "1 Orë",
    "3 hours" : "3 orë",
    "1 day" : "1 ditë ",
    "Your settings have been updated." : "Rregullimet tuaja u përditësuan",
    "None" : "Asnjë",
    "You need to set up your email address before you can receive notification emails." : "Kërkohet të caktoni adresën tuaj email, përpara se të mund të merrni email-e njoftimesh.",
    "seconds ago" : "sekonda më parë"
},
"nplurals=2; plural=(n != 1);");
